==> shared-ldap-0.9.8-sources.jar: org/apache/directory/shared/ldap/schema/syntax/RegexSyntaxChecker.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *  
 *    http://www.apache.org/licenses/LICENSE-2.0
 *  
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License. 
 *  
 */
package org.apache.directory.shared.ldap.schema.syntax;

import java.util.ArrayList;
import java.util.List;


/**
 * A SyntaxChecker implemented using Perl5 regular expressions to constrain
 * values.
 * 
 * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
 * @version $Rev: 510365 $
 */
public class RegexSyntaxChecker extends AbstractSyntaxChecker
{
    /** the set of regular expressions */
    private List<String> expressions;


    /**
     * Creates a Syntax validator for a specific Syntax using Perl5 matching
     * rules for validation.
     * 
     * @param oid
     *            the oid of the Syntax values checked
     * @param matchExprArray
     *            the array of matching expressions
     */
    public RegexSyntaxChecker( String oid, String[] matchExprArray )
    {
        super( oid );
        
        if ( ( matchExprArray != null ) && ( matchExprArray.length != 0 ) )
        {
            expressions = new ArrayList<String>( matchExprArray.length );
            
            for ( String regexp:matchExprArray )
            {
                expressions.add( regexp );
            }
        }
        else
        {
            expressions = new ArrayList<String>();
        }
    }


    /**
     * 
     * Creates a new instance of RegexSyntaxChecker.
     * 
     * @param oid the oid to associate with this new SyntaxChecker
     *
     */
    protected RegexSyntaxChecker( String oid )
    {
        super( oid );
        expressions = new ArrayList<String>();
    }
    
    /**
     * @see org.apache.directory.shared.ldap.schema.syntax.SyntaxChecker#isValidSyntax(java.lang.Object)
     */
    public boolean isValidSyntax( Object value )
    {
        String str = null;
        boolean match = true;

        if ( value instanceof String )
        {
            str = ( String ) value;

            for ( String regexp:expressions )
            {
                match = match && str.matches( regexp );

                if ( !match )
                {
                    break;
                }
            }
        }

        return match;
    }

    /**
     * Get the list of regexp stored into this SyntaxChecker
     * 
     * @return AN array containing all the stored regexp
     */
    public String[] getExpressions()
    {
        String[] exprs = new String[ expressions.size() ];
        return expressions.toArray( exprs );
    }

    /**
     * Add a list of regexp to be applied by this SyntaxChecker
     * 
     * @param expressions The regexp list to add
     */
    public void setExpressions( String[] expressions )
    {
        for ( String regexp:expressions )
        {
            this.expressions.add( regexp );
        }

    }
}

==> shared-ldap-0.9.11-sources.jar: org/apache/directory/shared/ldap/schema/syntax/RegexSyntaxChecker.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *  
 *    http://www.apache.org/licenses/LICENSE-2.0
 *  
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License. 
 *  
 */
package org.apache.directory.shared.ldap.schema.syntax;

import java.util.ArrayList;
import java.util.List;


/**
 * A SyntaxChecker implemented using Perl5 regular expressions to constrain
 * values.
 * 
 * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
 * @version $Rev: 657366 $
 */
public class RegexSyntaxChecker extends AbstractSyntaxChecker
{
    /** the set of regular expressions */
    private List<String> expressions;


    /**
     * Creates a Syntax validator for a specific Syntax using Perl5 matching
     * rules for validation.
     * 
     * @param oid
     *            the oid of the Syntax values checked
     * @param matchExprArray
     *            the array of matching expressions
     */
    public RegexSyntaxChecker( String oid, String[] matchExprArray )
    {
        super( oid );
        
        if ( ( matchExprArray != null ) && ( matchExprArray.length != 0 ) )
        {
            expressions = new ArrayList<String>( matchExprArray.length );
            
            for ( String regexp:matchExprArray )
            {
                expressions.add( regexp );
            }
        }
        else
        {
            expressions = new ArrayList<String>();
        }
    }


    /**
     * 
     * Creates a new instance of RegexSyntaxChecker.
     * 
     * @param oid the oid to associate with this new SyntaxChecker
     *
     */
    protected RegexSyntaxChecker( String oid )
    {
        super( oid );
        expressions = new ArrayList<String>();
    }
    
    /**
     * @see org.apache.directory.shared.ldap.schema.syntax.SyntaxChecker#isValidSyntax(java.lang.Object)
     * 
     * @param value the value of some attribute with the syntax
     * @return true if the value is in the valid syntax, false otherwise
     */
    public boolean isValidSyntax( Object value )
    {
        String str = null;
        boolean match = true;

        if ( value instanceof String )
        {
            str = ( String ) value;

            for ( String regexp:expressions )
            {
                match = match && str.matches( regexp );

                if ( !match )
                {
                    break;
                }
            }
        }

        return match;
    }

    /**
     * Get the list of regexp stored into this SyntaxChecker
     * 
     * @return AN array containing all the stored regexp
     */
    public String[] getExpressions()
    {
        String[] exprs = new String[ expressions.size() ];
        return expressions.toArray( exprs );
    }

    /**
     * Add a list of regexp to be applied by this SyntaxChecker
     * 
     * @param expressions The regexp list to add
     */
    public void setExpressions( String[] expressions )
    {
        for ( String regexp:expressions )
        {
            this.expressions.add( regexp );
        }

    }
}
